@@ -5,7 +5,8 @@ class SecureNativeOptions(object):
 
     def __init__(self, api_key=None, api_url="https://api.securenative.com/collector/api/v1", interval=1000,
                  max_events=1000, timeout=1500, auto_send=True, disable=False, log_level="CRITICAL",
-                 fail_over_strategy=FailOverStrategy.FAIL_OPEN.value, proxy_headers=None):
+                 fail_over_strategy=FailOverStrategy.FAIL_OPEN.value, proxy_headers=None,
+                 pii_headers=None, pii_regex_pattern=None):
 
         if proxy_headers is None:
             proxy_headers = []
@@ -24,3 +25,5 @@ class SecureNativeOptions(object):
         self.disable = disable
         self.log_level = log_level
         self.proxy_headers = proxy_headers
+        self.pii_headers = pii_headers
+        self.pii_regex_pattern = pii_regex_pattern
